%define anolis_release 1

%global glib2_version %(pkg-config --modversion glib-2.0 2>/dev/null || echo bad)
%global qmi_version %(pkg-config --modversion qmi-glib 2>/dev/null || echo bad)
%global mbim_version %(pkg-config --modversion mbim-glib 2>/dev/null || echo bad)
%global qrtr_version %(pkg-config --modversion qrtr-glib 2>/dev/null || echo bad)

Name: ModemManager
Version: 1.22.0
Release: %{anolis_release}%{?dist}
Summary: Mobile broadband modem management service
License: GPL-2.0-or-later
URL: http://www.freedesktop.org/wiki/Software/ModemManager/
Source: https://gitlab.com/linux-mobile-broadband/ModemManager/-/archive/%{version}/%{name}-%{version}.tar.bz2

# All of these are applied upstream. Can frop on rebase to 1.24
Patch0: 0001-shared-qmi-do-not-leak-a-string-in-error-path.patch
Patch1: 0001-ublox-helpers-fix-propagation-of-URAT-response-parse.patch
Patch2: 0003-broadband-modem-fix-a-potential-leak-in-cusd_process.patch
Patch3: 0004-shared-qmi-fix-a-leak-in-error-handling-path.patch
Patch4: 0005-quectel-shared-do-not-leak-name-string.patch
Patch5: 0006-port-qmi-fix-array-bound-check.patch
Patch6: 0007-mmcli-sms-do-not-leak-message_reference.patch
Patch7: 0008-bearer-qmi-fix-a-copy-n-paste-error.patch
Patch8: 0009-sim-qmi-do-not-leak-access-technology-name.patch
Patch9: 0010-libmm-glib-signal-fix-a-copy-n-paste-error.patch
Patch10: 0011-modem-helpers-do-not-leak-past-PDP-on-error.patch
Patch11: 0001-mmcli-fix-a-memory-leak.patch

# For mbim-proxy and qmi-proxy
Requires: libmbim-utils
Requires: libqmi-utils
Requires: %{name}-glib%{?_isa} = %{version}-%{release}

# Don't allow older versions of these than what we built against,
# because they add new API w/o versioning it or bumping the SONAME
Conflicts: glib2%{?_isa} < %{glib2_version}
Conflicts: libqmi%{?_isa} < %{qmi_version}
Conflicts: libmbim%{?_isa} < %{mbim_version}
Conflicts: libqrtr-glib%{?_isa} < %{qrtr_version}

Requires(post): systemd
Requires(postun): systemd
Requires(preun): systemd

Requires: polkit

BuildRequires: meson >= 0.53
BuildRequires: dbus-devel
BuildRequires: dbus-daemon
BuildRequires: gettext-devel >= 0.19.8
BuildRequires: glib2-devel >= 2.56
BuildRequires: gobject-introspection-devel >= 1.38
BuildRequires: gtk-doc
BuildRequires: libgudev1-devel >= 232
BuildRequires: libmbim-devel >= 1.30.0
BuildRequires: libqmi-devel >= 1.32.0
BuildRequires: libqrtr-glib-devel >= 1.0.0
BuildRequires: systemd
BuildRequires: systemd-devel >= 209
BuildRequires: vala
BuildRequires: polkit-devel

%global __provides_exclude ^libmm-plugin-

%description
The ModemManager service manages WWAN modems and provides a consistent API for
interacting with these devices to client applications.


%package devel
Summary: Libraries and headers for adding ModemManager support to applications
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: pkgconfig

%description devel
This package contains various headers for accessing some ModemManager functionality
from applications.


%package glib
Summary: Libraries for adding ModemManager support to applications that use glib.
License: LGPL-2.1-or-later
Requires: glib2 >= %{glib2_version}

%description glib
This package contains the libraries that make it easier to use some ModemManager
functionality from applications that use glib.


%package glib-devel
Summary: Libraries and headers for adding ModemManager support to applications that use glib.
License: LGPL-2.1-or-later
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: %{name}-devel%{?_isa} = %{version}-%{release}
Requires: %{name}-glib%{?_isa} = %{version}-%{release}
Requires: glib2-devel >= %{glib2_version}
Requires: pkgconfig

%description glib-devel
This package contains various headers for accessing some ModemManager functionality
from glib applications.


%package vala
Summary: Vala bindings for ModemManager
License: LGPL-2.1-or-later
Requires: vala
Requires: %{name}-glib%{?_isa} = %{version}-%{release}

%description vala
Vala bindings for ModemManager


%prep
%autosetup -p1


%build
# Let's avoid BuildRequiring bash-completion because it changes behavior
# of shell, at least until the .pc file gets into the -devel subpackage.
# We'll just install the bash-completion file ourselves.
%meson \
	-Ddist_version='"%{version}-%{release}"' \
	-Dudevdir=/usr/lib/udev \
	-Dsystemdsystemunitdir=%{_unitdir} \
	-Dvapi=true \
	-Dgtk_doc=true \
	-Dpolkit=permissive \
	-Dbash_completion=false
%meson_build


%install
%meson_install
find %{buildroot}%{_datadir}/gtk-doc |xargs touch --reference meson.build
%find_lang %{name}
mkdir -p %{buildroot}%{_datadir}/bash-completion/completions/
cp -a cli/mmcli-completion %{buildroot}%{_datadir}/bash-completion/completions/mmcli


%check
# meson_test


%ldconfig_scriptlets glib


%post
%systemd_post ModemManager.service


%preun
%systemd_preun ModemManager.service


%postun
%systemd_postun ModemManager.service


%files -f %{name}.lang
%license COPYING
%doc README
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.ModemManager1.conf
%{_datadir}/dbus-1/system-services/org.freedesktop.ModemManager1.service
%attr(0755,root,root) %{_sbindir}/ModemManager
%attr(0755,root,root) %{_bindir}/mmcli
%dir %{_libdir}/%{name}
%attr(0755,root,root) %{_libdir}/%{name}/*.so*
%{_udevrulesdir}/*
%{_datadir}/polkit-1/actions/*.policy
%{_unitdir}/ModemManager.service
%{_datadir}/icons/hicolor/22x22/apps/*.png
%{_datadir}/bash-completion
%{_datadir}/ModemManager
%{_mandir}/man1/*
%{_mandir}/man8/*


%files devel
%{_includedir}/ModemManager/
%dir %{_datadir}/gtk-doc/html/%{name}
%{_datadir}/gtk-doc/html/%{name}/*
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/dbus-1/interfaces/*.xml


%files glib
%license COPYING
%{_libdir}/libmm-glib.so.*
%{_libdir}/girepository-1.0/*.typelib


%files glib-devel
%{_libdir}/libmm-glib.so
%dir %{_includedir}/libmm-glib
%{_includedir}/libmm-glib/*.h
%{_libdir}/pkgconfig/mm-glib.pc
%dir %{_datadir}/gtk-doc/html/libmm-glib
%{_datadir}/gtk-doc/html/libmm-glib/*
%{_datadir}/gir-1.0/*.gir


%files vala
%{_datadir}/vala/vapi/libmm-glib.*


%changelog
* Fri Feb 14 2025 Zhao Hang <wb-zh951434@alibaba-inc.com> - 1.22.0-1
- Refer to CentOS Stream ModemManager-1.22.0-7 (tdawson@redhat.com)

* Sun Jan 15 2023 Funda Wang <fundawang@yeah.net> - 1.18.12-1
- New version 1.18.12

* Mon Mar 14 2022 Yaobin Shi <shiyaobin.syb@alibaba-inc.com> - 1.18.6-2
- Enable make check for Anolis OS 23
- Add BuildRequires python3-gobject and python3-dbus

* Thu Mar 10 2022 Larry Shi <larryshi@openanolis.org> - 1.18.6-1
- Init for Anolis OS 23
